pub type Ptr<A> = Arc<A>;Expand description
The reference counting pointer type used throughout the engine.
Aliased Type
pub struct Ptr<A> { /* private fields */ }pub type Ptr<A> = Arc<A>;The reference counting pointer type used throughout the engine.
pub struct Ptr<A> { /* private fields */ }